verify

Function verify 

pub fn verify<const M: usize, D: Digest>(
    shared_state: &impl Digestable,
    data: Data<'_>,
    proof: &NiProof<M>,
    rng: &mut impl RngCore,
) -> Result<(), InvalidProof>
Verify the proof, deriving challenge independently from same data

Rng is used for primality checking of input data